Struct atomic_refcell::AtomicRefMut
[−]
[src]
pub struct AtomicRefMut<'b, T: ?Sized + 'b> { /* fields omitted */ }A wrapper type for a mutably borrowed value from an AtomicRefCell<T>.
Methods
impl<'b, T: ?Sized> AtomicRefMut<'b, T>[src]
pub fn map<U: ?Sized, F>(orig: AtomicRefMut<'b, T>, f: F) -> AtomicRefMut<'b, U> where
F: FnOnce(&mut T) -> &mut U, [src]
F: FnOnce(&mut T) -> &mut U,
Make a new AtomicRefMut for a component of the borrowed data, e.g. an enum
variant.